pub struct BACnetAccessRule {
pub time_range_specifier: u32,
pub time_range: Option<(Date, Time, Date, Time)>,
pub location_specifier: u32,
pub location: Option<BACnetDeviceObjectReference>,
pub enable: bool,
}Expand description
BACnet Access Rule for access control objects.
Specifies a time range and location with an enable/disable flag, used in positive and negative access rules lists.
Fields
time_range_specifier: u32Time range specifier: 0 = specified, 1 = always.
time_range: Option<(Date, Time, Date, Time)>Optional time range (start date, start time, end date, end time).
Present only when time_range_specifier is 0 (specified).
location_specifier: u32Location specifier: 0 = specified, 1 = all.
location: Option<BACnetDeviceObjectReference>Optional location reference. Present only when location_specifier is 0 (specified).
enable: boolWhether access is enabled or disabled by this rule.